#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_GROUP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_GROUP_HPP_INCLUDED

#include <boost/simd/swar/include/functions/group.hpp>

#endif
